@@ -1,9 +1,9 @@
-import json
 import inspect
+from django.core.serializers.json import DjangoJSONEncoder
 from _base import BaseExporter
 
 
-class JSONGeneratorEncoder(json.JSONEncoder):
+class JSONGeneratorEncoder(DjangoJSONEncoder):
     "Handle generator objects and expressions."
     def default(self, obj):
         if inspect.isgenerator(obj):
@@ -13,6 +13,7 @@ class JSONGeneratorEncoder(json.JSONEncoder):
 
 class JSONExporter(BaseExporter):
     file_extension = 'json'
+    content_type = 'application/json'
     preferred_formats = ('number', 'string')
 
     def write(self, iterable, buff=None):
